==> dcl_5.3-1.tar.gz: dcl-5.3/src/grph1/szpack/szstni.f <==
*-----------------------------------------------------------------------
*     TONE PATTERN ATTRIBUTE
*-----------------------------------------------------------------------
*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
*-----------------------------------------------------------------------
      SUBROUTINE SZSTNI(ITPAT)

      PARAMETER (MAXCLI=100)

      INTEGER   ICPAT(MAXCLI)
      LOGICAL   LFRST,LTNATR,LCLATR,LSOFTF,LHARD,LCL2TN,LMONOF,LMSG
      CHARACTER CMSG*80

      SAVE

      DATA      LFRST/.TRUE./, LMSG/.TRUE./


*     / INITIALIZE /

      ITPATZ=ITPAT

      IF (LFRST) THEN

        CALL SWQTNC(LTNATR)
        CALL SWQCLC(LCLATR)

        CALL SGLGET('LCL2TN',LCL2TN)

        IF (LCL2TN) THEN
          LMONOF=.TRUE.
        ELSE
          IF (LCLATR) THEN
            LMONOF=.FALSE.
          ELSE
            LMONOF=.TRUE.
          END IF
        END IF

        IF (LMONOF) THEN
          CALL SZCLTN(ICPAT, MAXCLI)
          CALL MSGDMP('M','SZSTNI',
     +         'COLOR TO TONE CONVERSION TABLE IS USED.')
        END IF

        LFRST=.FALSE.

      END IF

*     / SOFT FILL OR HARD FILL /

      CALL SGLGET('LSOFTF',LSOFTF)

      IF (LSOFTF) THEN
        LHARD=.FALSE.
      ELSE
        IF (LTNATR) THEN
          LHARD=.TRUE.
        ELSE
          LHARD=.FALSE.
          IF (LMSG) THEN
            CALL MSGDMP('W','SZSTNI','HARD FILL IS NOT SUPPORTED.')
            LMSG=.FALSE.
          END IF
        END IF
      END IF

      CALL SZSTMD(LHARD)

*     / COLOR TO TONE CONVERSION /

      IF (LMONOF) THEN
        LP=MOD(ITPATZ,1000)
        LC=ITPATZ/1000
        IF (LP.EQ.999) THEN
          IF (1.LE.LC .AND. LC.LE.MAXCLI) THEN
            IF (ICPAT(LC).GE.0) THEN
              ITPATZ=ICPAT(LC)
            ELSE
              CMSG='COLOR NUMBER ## IS NOT DEFINED IN CL2TNMAP.'
              CALL CHNGI(CMSG,'##',LC,'(I2)')
              CALL MSGDMP('W','SWGTON',CMSG)
            END IF
          ELSE
            CMSG='COLOR NUMBER ## IS NOT DEFINED IN CL2TNMAP.'
            CALL CHNGI(CMSG,'##',LC,'(I2)')
            CALL MSGDMP('W','SWGTON',CMSG)
          END IF
        END IF
      END IF

      IF (LHARD) THEN
        CALL SZTITZ(ITPATZ)
      ELSE
        CALL SZTITS(ITPATZ)
      END IF

      RETURN
*-----------------------------------------------------------------------
      ENTRY SZQTNI(ITPAT)

      ITPAT=ITPATZ

      RETURN
      END

==> dcl_5.3.3.orig.tar.gz: dcl-5.3.3/src/grph1/szpack/szstni.f <==
*-----------------------------------------------------------------------
*     TONE PATTERN ATTRIBUTE
*-----------------------------------------------------------------------
*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
*-----------------------------------------------------------------------
      SUBROUTINE SZSTNI(ITPAT)

      PARAMETER (MAXCLI=100)

      INTEGER   ICPAT(MAXCLI)
      LOGICAL   LFRST,LTNATR,LCLATR,LSOFTF,LHARD,LCL2TN,LMONOF,LMSG
      CHARACTER CMSG*80

      SAVE

      DATA      LFRST/.TRUE./, LMSG/.TRUE./


*     / INITIALIZE /

      ITPATZ=ITPAT
      CALL SGIGET('IBGCLI',IBGCLI)

      IF (LFRST) THEN

        CALL SWQTNC(LTNATR)
        CALL SWQCLC(LCLATR)

        CALL SGLGET('LCL2TN',LCL2TN)

        IF (LCL2TN) THEN
          LMONOF=.TRUE.
        ELSE
          IF (LCLATR) THEN
            LMONOF=.FALSE.
          ELSE
            LMONOF=.TRUE.
          END IF
        END IF

        IF (LMONOF) THEN
          CALL SZCLTN(ICPAT, MAXCLI)
          CALL MSGDMP('M','SZSTNI',
     +         'COLOR TO TONE CONVERSION TABLE IS USED.')
        END IF

        LFRST=.FALSE.

      END IF

*     / SOFT FILL OR HARD FILL /

      CALL SGLGET('LSOFTF',LSOFTF)

      IF (LSOFTF) THEN
        LHARD=.FALSE.
      ELSE
        IF (LTNATR) THEN
          LHARD=.TRUE.
        ELSE
          LHARD=.FALSE.
          IF (LMSG) THEN
            CALL MSGDMP('W','SZSTNI','HARD FILL IS NOT SUPPORTED.')
            LMSG=.FALSE.
          END IF
        END IF
      END IF

      CALL SZSTMD(LHARD)

*     / COLOR TO TONE CONVERSION /

      IF (LMONOF) THEN
        LP=MOD(ITPATZ,1000)
        LC=ITPATZ/1000
        IF (LP.EQ.999 .AND. LC.NE.IBGCLI) THEN
          IF (1.LE.LC .AND. LC.LE.MAXCLI) THEN
            IF (ICPAT(LC).GE.0) THEN
              ITPATZ=ICPAT(LC)
            ELSE
              CMSG='COLOR NUMBER ## IS NOT DEFINED IN CL2TNMAP.'
              CALL CHNGI(CMSG,'##',LC,'(I2)')
              CALL MSGDMP('W','SWGTON',CMSG)
            END IF
          ELSE
            CMSG='COLOR NUMBER ## IS NOT DEFINED IN CL2TNMAP.'
            CALL CHNGI(CMSG,'##',LC,'(I2)')
            CALL MSGDMP('W','SWGTON',CMSG)
          END IF
        END IF
      END IF

      ITCLIY=ITPATZ/1000
      ITPNMY=MOD(ITPATZ,1000)
      IF (ITCLIY.EQ.IBGCLI) THEN
        ITPATY=ITPNMY
      ELSE
        IF (ITCLIY.EQ.0) ITCLIY=1
        ITPATY=ITPNMY+ITCLIY*1000
      END IF

      IF (LHARD) THEN
        CALL SZTITZ(ITPATY)
      ELSE
        CALL SZTITS(ITPATY)
      END IF

      RETURN
*-----------------------------------------------------------------------
      ENTRY SZQTNI(ITPAT)

      ITPAT=ITPATY

      RETURN
      END
